/*
 * abissd/abissd.h - abissd, common definitions, exported to plugins
 *
 * Written 2004 by Werner Almesberger
 *
 * (C) Copyright Koninklijke Philips Electronics NV 2004. All rights reserved.
 * For licensing and warranty information, see the file ../../COPYING.LGPLv21
 */

/*
 * This is the ONLY file from abissd that plugins should include.
 */

#ifndef ABISSD_H
#define ABISSD_H

#include <abiss_msg.h>
#include <abissd_msg.h>


/* ----- rm.c -------------------------------------------------------------- */


struct rm {
    int byterate;
    int bufsize;
    int num_extents;
    struct abissd_extent *extents;
};


int rm_reserve(struct rm *rm);
void rm_return(const struct rm *rm);


/* ----- stream.c ---------------------------------------------------------- */


struct sched_ops;

struct stream {
    struct abissd_id id;
    const struct sched_ops *sched_ops;
    struct rm rm;
    struct stream *next;
};


/* ----- abissd.c and sched.c ---------------------------------------------- */


/* 
 * All function pointers in "struct sched_ops" may be NULL.
 */

struct sched_ops {
   const char *name;
   void (*init)(void);
   void (*print_params)(struct abissd_open_msg *msg);
   int (*open)(struct stream *stream,struct abissd_open_msg *msg);
   void (*close)(struct stream *stream);
};


extern int verbose;

void send_unsolicited(const struct stream *stream,
  struct abissd_unsolicited_msg *msg,size_t size);


/* ----- var.c ------------------------------------------------------------- */


void var_register(const struct sched_ops *sched_ops,
  const char *name,char type,const char *desc);

void var_set_int(const char *name,int value);
void var_set_float(const char *name,double value);
void var_set_str(const char *name,const char *value);

void var_set(const char *name,const char *value);
void var_assignment(const char *expr);

int var_is_set(const char *name);

int var_get_int(const char *name);
double var_get_float(const char *name);
const char *var_get_str(const char *name);


/* ------------------------------------------------------------------------- */


/*
 * We'd like to know what license a plugin is under. Currently, this
 * information is just printed, but may be used for other purposes (tainting,
 * selective export, etc. in the future).
 */

#define PLUGIN_LICENSE(s) \
  const char license[] = s

#endif /* ABISSD_H */
