/*
 * MiddlewareTest.h - CPPUnit test for libabiss middleware library
 *
 * Written 2004 by Erik Bos, Jennifer Blijlevens and Giel de Nijs
 *
 * (C) Copyright Koninklijke Philips Electronics NV 2004. All rights reserved.
 * For licensing and warranty information, see the file ../../COPYING.GPLv2
 */

#include "cppunit/TestCase.h"
#include "cppunit/extensions/HelperMacros.h"

#define DEFAULT_BUFSIZE  4 * 1024

using namespace CppUnit;

/**
 * @file
 * The test for middleware.
 */
class MiddlewareTest:public TestCase {
      public:
	MiddlewareTest();
	virtual ~ MiddlewareTest();

	// inherited from TestCase
	void setUp();
	void tearDown();

	// Test suite and test registration
	 CPPUNIT_TEST_SUITE(MiddlewareTest);

	 CPPUNIT_TEST(test_abiss_failing_fopen);
	 CPPUNIT_TEST(test_abiss_fopen_fclose_byterate_OK);
	 CPPUNIT_TEST(test_abiss_fopen_fclose_byterate_fail);
	 CPPUNIT_TEST(test_abiss_fopen_fclose_buffersize_OK);
	 CPPUNIT_TEST(test_abiss_fopen_fclose_buffersize_fail);
	 CPPUNIT_TEST(test_abiss_fwrite);
	 CPPUNIT_TEST(test_abiss_fread);

	 CPPUNIT_TEST(test_abiss_fseek);
	 CPPUNIT_TEST(test_abiss_fseeko);
	 CPPUNIT_TEST(test_abiss_ftell);
	 CPPUNIT_TEST(test_abiss_ftello);

	 CPPUNIT_TEST(test_abiss_failing_open);
	 CPPUNIT_TEST(test_abiss_open_close_byterate_OK);
	 CPPUNIT_TEST(test_abiss_open_close_byterate_fail);
	 CPPUNIT_TEST(test_abiss_open_close_buffersize_OK);
	 CPPUNIT_TEST(test_abiss_open_close_buffersize_fail);
	 CPPUNIT_TEST(test_abiss_write);
	 CPPUNIT_TEST(test_abiss_read);

	 CPPUNIT_TEST(test_abiss_lseek);

	 CPPUNIT_TEST_SUITE_END();

	void test_abiss_failing_fopen();
	void test_abiss_fopen_fclose_byterate_OK();
	void test_abiss_fopen_fclose_byterate_fail();
	void test_abiss_fopen_fclose_buffersize_OK();
	void test_abiss_fopen_fclose_buffersize_fail();
	void test_abiss_fread();
	void test_abiss_fwrite();
	void test_abiss_fseek();
	void test_abiss_fseeko();
	void test_abiss_ftell();
	void test_abiss_ftello();

	void test_abiss_failing_open();
	void test_abiss_open_close_byterate_OK();
	void test_abiss_open_close_byterate_fail();
	void test_abiss_open_close_buffersize_OK();
	void test_abiss_open_close_buffersize_fail();
	void test_abiss_read();
	void test_abiss_write();
	void test_abiss_lseek();

      private:

	char m_buf[DEFAULT_BUFSIZE];

};
