/*
 * seq_test.c - Sequence number access tester
 *
 * Written 2005 by Werner Almesberger
 *
 * (C) Copyright Koninklijke Philips Electronics NV 2005. All rights reserved.
 * For licensing and warranty information, see the file ../../COPYING.GPLv2
 */

#include "seq.h"

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <assert.h>

#define BUF_SIZE	1000000
#define MAX_STEP	3000
#define INITIAL_SEQ	0x205080b0

static unsigned char buf[BUF_SIZE+2]; /* 2 guard bytes */
static unsigned char zero[MAX_STEP];


static void fill_buf(int step)
{
    int offset;

    seq = INITIAL_SEQ;
    reset_sequence();
    for (offset = 1; offset <= BUF_SIZE; offset += step) {
	int len = offset+step > BUF_SIZE+1 ? BUF_SIZE+1-offset : step;
	unsigned char before,after;

	before = buf[offset-1];
	after = buf[offset+len];
	buf[offset-1] = 0xff;
	buf[offset+len] = 0xff;
	put_sequence(buf+offset,len);
	assert(buf[offset-1] == 0xff);
	assert(buf[offset+len] == 0xff);
	buf[offset-1] = before;
	buf[offset+len] = after;
    }
}


static void check_buf(int step)
{
    int offset;

    seq = INITIAL_SEQ;
    reset_sequence();
    for (offset = 1; offset <= BUF_SIZE; offset += step) {
	int len = offset+step > BUF_SIZE+1 ? BUF_SIZE+1-offset : step;

	if (check_sequence(buf+offset,len)) {
	    fprintf(stderr,"sequence error at offset %d\n",offset);
	    exit(1);
	}
    }
}


static void validate(int step)
{
    int offset;

    seq = INITIAL_SEQ;
    for (offset = 1; offset <= BUF_SIZE; offset += 1024) {
	int len = offset+1024 > BUF_SIZE+1 ? BUF_SIZE+1-offset : 1024;

	if (len <= 4)
	    assert(!memcmp(&seq,buf+offset,len));
	else {
	    assert(!memcmp(&seq,buf+offset,4));
	    if (len > 1024)
		len = 1024;
	    assert(!memcmp(zero,buf+offset+4,len-4));
	}
	seq++;
    }
}


int main(void)
{
    int i;

    for (i = 1; i <= MAX_STEP; i++) {
	memset(buf,0,BUF_SIZE+2);
	fill_buf(i);
	check_buf(i);
	validate(i);
    }
    return 0;
}
