/*
 * tests/elv/Kglue.h - Set up "kernel" internals
 *
 * Written 2004 by Werner Almesberger
 *
 * (C) Copyright Koninklijke Philips Electronics NV 2004. All rights reserved.
 * For licensing and warranty information, see the file ../../COPYING.GPLv2
 */

/*
 * Can be included both in user space and in "kernel". Note that we treat a
 * few things as opaque types.
 */


#ifndef kGLUE_H
#define kGLUE_H

enum {
	REQ_RW		= (1 << 0),
	REQ_SOFTBARRIER = (1 << 1),
	REQ_HARDBARRIER = (1 << 2),
	REQ_PM_SUSPEND	= (1 << 3),
	REQ_PM_RESUME	= (1 << 4),
	REQ_NOMERGE	= (1 << 5),
	REQ_STARTED	= (1 << 6),
	REQ_QUIET	= (1 << 7),
	REQ_DONTPREP	= (1 << 8),
	REQ_CMD		= (1 << 9),
	REQ_FAILFAST	= (1 << 10),
	REQ_DRIVE_CMD	= (1 << 11),
	REQ_PM_SHUTDOWN	= (1 << 12),
	REQ_BAR_FLUSH	= (1 << 13),
	REQ_ABISS	= (1 << 16), /* hack: request uses ABISS */
	REQ_ABISS_HEAD	= (1 << 17), /* hack: enqueue at head */
	REQ_ABISS_TAIL	= (1 << 18), /* hack: enqueue at tail */
	/* 29...31 are reserved for the priority */
};

#define REQ_ABISS_PRIO(n) ((n) << 29)
#define REQ_ABISS_GET_PRIO(flags) (((flags) >> 29) & 7)

enum {
	READ = 0,	/* just make it very explicit */
	WRITE = 1,
};


extern int verbose;
extern int debug_level;
extern int dump_queue;


struct request;

void init_kernel(void);
void shutdown_kernel(void);

#define RQ_GET	1	/* dequeue: fetch request */
#define RQ_END	2	/* dequeue: complete request */

struct request *concoct_rq(int flags,int start,int secs);
void enqueue(struct request *rq);
void dequeue(int mode,struct request *rq,const char *id,const char *file,
    int line,...);
void upgrade(int offset,int prio);
void queue_empty(void);

void phase(int rw);

void show_queue(void);

void do_script(void);

#endif /* kGLUE_H */
