/*
 * tests/elv/Main.c - Run an elevator test
 *
 * Written 2004 by Werner Almesberger
 *
 * (C) Copyright Koninklijke Philips Electronics NV 2004. All rights reserved.
 * For licensing and warranty information, see the file ../../COPYING.GPLv2
 */


#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>

#include "Kglue.h"


int verbose = 0;
int debug_level = 0;
int dump_queue = 0;


static void usage(const char *name)
{
	fprintf(stderr,
"usage: %s [-q] [-v] [debug_level]\n\n"
"  -q   ignore dequeue commands, and print entire queue at end\n"
"  -v   verbose mode\n"
  ,name);
	exit(1);
}


int main(int argc,char **argv)
{
	int c;

	while ((c = getopt(argc,argv,"qv")) != EOF)
		switch (c) {
			case 'q':
				dump_queue = 1;
				break;
			case 'v':
				verbose = 1;
				break;
			default:
				usage(*argv);
		}
	switch (argc-optind) {
		char *end;

		case 1:
			verbose = 1;
			debug_level = strtoul(argv[optind],&end,0);
			if (*end)
				usage(*argv);
			break;
		case 0:
			break;
		default:
			usage(*argv);
	}
	init_kernel();
	do_script();
	if (dump_queue)
		show_queue();
	else
		queue_empty();
	shutdown_kernel();
	return 0;
}
